@@ -6,7 +6,7 @@
 # Description: Overleaf API Wrapper
 # Author: Moritz Glöckl
 # License: MIT
-# Version: 1.1.1
+# Version: 1.1.3
 ##################################################
 
 import requests as reqs
@@ -33,6 +33,14 @@ class OverleafClient(object):
     uploading a file to a project.
     """
 
+    @staticmethod
+    def filter_projects(json_content, more_attrs=None):
+        more_attrs = more_attrs or {}
+        for p in json_content:
+            if not p.get("archived") and not p.get("trashed"):
+                if all(p.get(k) == v for k, v in more_attrs.items()):
+                    yield p
+
     def __init__(self, cookie=None, csrf=None):
         self._cookie = cookie  # Store the cookie for authenticated requests
         self._csrf = csrf  # Store the CSRF token since it is needed for some requests
@@ -64,17 +72,22 @@ class OverleafClient(object):
             # Enrich cookie with gke-route cookie from GET request above
             self._cookie['gke-route'] = get_login.cookies['gke-route']
 
+            # CSRF changes after making the login request, new CSRF token will be on the projects page
+            projects_page = reqs.get(PROJECT_URL, cookies=self._cookie)
+            self._csrf = BeautifulSoup(projects_page.content, 'html.parser').find('meta', {'name': 'ol-csrfToken'}) \
+                .get('content')
+
             return {"cookie": self._cookie, "csrf": self._csrf}
 
     def all_projects(self):
         """
-        Get all of a user's active projects (= not archived)
+        Get all of a user's active projects (= not archived and not trashed)
         Returns: List of project objects
         """
         projects_page = reqs.get(PROJECT_URL, cookies=self._cookie)
         json_content = json.loads(
-            BeautifulSoup(projects_page.content, 'html.parser').find('script', {'id': 'data'}).contents[0])
-        return list(filter(lambda x: not x.get("archived"), json_content.get("projects")))
+            BeautifulSoup(projects_page.content, 'html.parser').find('meta', {'name': 'ol-projects'}).get('content'))
+        return list(OverleafClient.filter_projects(json_content))
 
     def get_project(self, project_name):
         """
@@ -85,10 +98,8 @@ class OverleafClient(object):
 
         projects_page = reqs.get(PROJECT_URL, cookies=self._cookie)
         json_content = json.loads(
-            BeautifulSoup(projects_page.content, 'html.parser').find('script', {'id': 'data'}).contents[0])
-        return next(
-            filter(lambda x: not x.get("archived") and x.get("name") == project_name, json_content.get("projects")),
-            None)
+            BeautifulSoup(projects_page.content, 'html.parser').find('meta', {'name': 'ol-projects'}).get('content'))
+        return next(OverleafClient.filter_projects(json_content, {"name": project_name}), None)
 
     def download_project(self, project_id):
         """
@@ -114,17 +125,21 @@ class OverleafClient(object):
 
         params = {
             "parent_folder_id": parent_folder_id,
-            "_csrf": self._csrf,
             "name": folder_name
         }
+        headers = {
+            "X-Csrf-Token": self._csrf
+        }
         r = reqs.post(FOLDER_URL.format(project_id),
-                      cookies=self._cookie, json=params)
+                      cookies=self._cookie, headers=headers, json=params)
 
         if r.ok:
             return json.loads(r.content)["_id"]
         elif r.status_code == str(400):
             # Folder already exists
             return
+        else:
+            raise reqs.HTTPError()
 
     def get_project_infos(self, project_id):
         """
@@ -146,9 +161,9 @@ class OverleafClient(object):
         # Convert cookie from CookieJar to string
         cookie = "gke-route={}; overleaf_session2={}" \
             .format(
-                reqs.utils.dict_from_cookiejar(self._cookie)["gke-route"],
-                reqs.utils.dict_from_cookiejar(self._cookie)["overleaf_session2"]
-            )
+            reqs.utils.dict_from_cookiejar(self._cookie)["gke-route"],
+            reqs.utils.dict_from_cookiejar(self._cookie)["overleaf_session2"]
+        )
 
         # Connect to Overleaf Socket.IO, send a time parameter and the cookies
         socket_io = SocketIO(
